==> lk21-1.3.60-py3-none-any.whl: lk21/extractors/layarkaca21.py <==
from . import BaseExtractor


class Layarkaca21(BaseExtractor):
    tag = "movie"
    host = "http://149.56.24.226/"

    def extract(self, id: str):
        raw = self.session.post("http://dl.sharemydrive.xyz/verifying.php",
                                headers={
                                    "Content-Type": "application/x-www-form-urlencoded; charset=UTF-8",
                                    "Accept": "*/*",
                                    "X-Requested-With": "XMLHttpRequest"
                                },
                                params={"slug": id},
                                data={"slug": id}
                                )
        soup = self.soup(raw)
        tb = soup.find("tbody")

        result = {}
        for tr in tb.findAll("tr"):
            title = tr.find("strong").text
            result[title] = {}
            for td in tr.findAll("td")[1:]:
                if (a := td.a):
                    result[title][a["class"]
                                  [-1].split("-")[-1]] = a["href"]
        return result

    def search(self, title: str, page=1):
        if page > 1:
            return
        raw = self.session.get(self.host,
                               params={"s": title})

        soup = self.soup(raw)

        r = []
        for item in soup.findAll(class_="search-item"):
            a = item.a
            extra = {"genre": [], "star": [], "country": [],
                     "size": [""], "quality": [""], "year": [""]}
            for tag in item.find(class_="cat-links").findAll("a"):
                name, it = self.re.findall(r"/([^/]+)/([^/]+)", str(tag))[0]
                extra[name].insert(0, it)

            for p in filter(lambda x: x.strong is not None, item.findAll("p")):
                np, vl = self.re.findall(
                    r"^([^:]+):\s+(.+)", p.text.strip())[0]
                np = "star" if np == "Bintang" else "director" if np == "Sutradara" else np
                extra[np] = self.re.split(r"\s*,\s*", vl) if "," in vl else vl

            extra["id"] = self.re.search(
                r"\w/([^/]+)", a["href"]).group(1)
            result = {
                "title": (item.find("h2").text or a.img["alt"]).strip(),
            }
            result.update(extra)
            r.append(result)
        return r

==> lk21-1.4.7-py3-none-any.whl: lk21/extractors/layarkaca21.py <==
from . import BaseExtractor


class Layarkaca21(BaseExtractor):
    tag = "movie"
    host = "http://149.56.24.226/"

    def extract(self, id: str) -> dict:
        """
        Ambil semua situs unduhan dan metadata dari halaman web

        Args:
              id: jalur url dimulai setelah host, type 'str'

        Returns:
              dict: hasil 'scrape' halaman web
        """

        raw = self.session.post("http://dl.sharemydrive.xyz/verifying.php",
                                headers={
                                    "Content-Type": "application/x-www-form-urlencoded; charset=UTF-8",
                                    "Accept": "*/*",
                                    "X-Requested-With": "XMLHttpRequest"
                                },
                                params={"slug": id},
                                data={"slug": id}
                                )
        soup = self.soup(raw)
        tb = soup.find("tbody")

        result = {}
        for tr in tb.findAll("tr"):
            title = tr.find("strong").text
            result[title] = {}
            for td in tr.findAll("td")[1:]:
                if (a := td.a):
                    result[title][a["class"]
                                  [-1].split("-")[-1]] = a["href"]
        return result

    def search(self, query: str, page: int = 1) -> list:
        """
        Cari item berdasarkan 'query' yang diberikan

        Args:
              query: kata kunci pencarian, type 'str'
              page: indeks halaman web, type 'int'

        Returns:
              list: daftar item dalam bentuk 'dict'
        """

        raw = self.session.get(self.host,
                               params={"s": query})

        soup = self.soup(raw)

        r = []
        for item in soup.findAll(class_="search-item"):
            a = item.a
            extra = {"genre": [], "star": [], "country": [],
                     "size": [""], "quality": [""], "year": [""]}
            for tag in item.find(class_="cat-links").findAll("a"):
                name, it = self.re.findall(r"/([^/]+)/([^/]+)", str(tag))[0]
                extra[name].insert(0, it)

            for p in filter(lambda x: x.strong is not None, item.findAll("p")):
                np, vl = self.re.findall(
                    r"^([^:]+):\s+(.+)", p.text.strip())[0]
                np = "star" if np == "Bintang" else "director" if np == "Sutradara" else np
                extra[np] = self.re.split(r"\s*,\s*", vl) if "," in vl else vl

            extra["id"] = self.re.search(
                r"\w/([^/]+)", a["href"]).group(1)
            result = {
                "title": (item.find("h2").text or a.img["alt"]).strip(),
            }
            result.update(extra)
            r.append(result)
        return r
